@@ -1,6 +1,6 @@
 import yaml
 import os
-from typing import Tuple
+from typing import Tuple, Optional
 from copy import deepcopy
 
 from insight_plugin import FILE_ENCODING
@@ -68,7 +68,7 @@ def manifest_to_spec(connector_folder: str, output_dir: str) -> str:
     except Exception as error_message:
         print(f"Error caused when creating the spec file - {error_message}")
         raise error_message
-    
+
     try:
         user_needed = get_user_type(connector_folder)
     except Exception as error_message:
@@ -115,7 +115,7 @@ def get_plugin_name(connector_manifest: str) -> Tuple[str, str]:
     :param str connector_folder: the name of the folder the connector is in
     :return Tuple[str, str]: The plugin name nad title that has been generated from the manifests name field
     """
-    
+
     plugin_name = connector_manifest.get("id", "").replace(".", "_")
 
 
@@ -155,11 +155,100 @@ def get_actions(connector_manifest: dict) -> dict:
 
     actions = {}
 
-    for action in connector_manifest.get("functions"):
-        action_name = action.get("id").split(".")[-1]
+    # This is a common param for the actions
+    execution_id_param = {
+        "name": "execution_id",
+        "schema": {
+            "type": "string",
+        },
+    }
+    # This is a common return for both starting an import function and retrieving its status
+    import_function_status_return = {
+        'name': 'import_function_status',
+        'type': 'string',
+        'enum': [
+            'running',
+            'completed',
+            'failed',
+            'stopped',
+        ],
+        'nullable': False,
+    }
 
+    functions = connector_manifest.get("functions", [])
+    # Add the status check function for import functions
+    functions.append({
+        "id": "get_orchestrator_update",
+        "name": "Get Orchestrator Update",
+        "description": "Get the status of a running import function",
+        "parameters": [
+            execution_id_param,
+        ],
+        "returns": [
+            import_function_status_return,
+        ],
+        "entrypoint": "get_orchestrator_update",
+    })
+    # Add the stop function for import functions
+    functions.append({
+        "id": "stop_import_function",
+        "name": "Stop Import Function",
+        "description": "Stop a running import function",
+        "parameters": [
+            execution_id_param,
+        ],
+        "returns": [
+            import_function_status_return,
+        ],
+        "entrypoint": "stop_import_function",
+    })
+
+    for action in functions:
         dict_of_inputs = {}
-        for input_item in action.get("parameters"):
+        if action.get('type') == 'import':
+            # import functions all have the same inputs
+            action['parameters'] = [
+                {
+                    'name': 'settings',
+                    'schema': {
+                        'type': 'object',
+                    },
+                },
+                {
+                    'name': 'high_water_mark',
+                    'schema': {
+                        'type': 'object',
+                    },
+                },
+                {
+                    'name': 'import_configuration_items',
+                    'schema': {
+                        'type': 'array',
+                        'items': {
+                            'type': 'object',
+                        },
+                    },
+                },
+                {
+                    'name': 'custom_import_parameters',
+                    'schema': {
+                        'type': 'object',
+                    },
+                },
+                {
+                    'name': 'execution_id',
+                    'schema': {
+                        'type': 'string',
+                    },
+                    'nullable': False,
+                }
+            ]
+            # and outputs
+            action['returns'] = [
+                import_function_status_return,
+            ]
+
+        for input_item in action.get("parameters", []):
             if input_item.get("name"):
                 parameter_name = input_item.get("name")
                 parameter_name, action_parameter_values = process_action(
@@ -188,10 +277,23 @@ def get_actions(connector_manifest: dict) -> dict:
                 }
                 break
 
-            parameter_name, action_parameter_values = process_action(
-                connector_manifest=deepcopy(connector_manifest),
-                parameter_name=parameter_name,
-            )
+            # similar handling to inputs, we need to check if the output item has a name
+            # if it does, we will use that as the name, if not we will use the
+            # name that is in the action_parameter_values object
+            # this is because some of the output items are not named in the manifest file
+            # so we need to use the name that is in the action_parameter_values object
+            if output_item.get("name"):
+                parameter_name = output_item.get("name")
+                parameter_name, action_parameter_values = process_action(
+                    parameter_name=parameter_name,
+                    action_parameter_values=output_item,
+                )
+            else:
+                parameter_name, action_parameter_values = process_action(
+                    connector_manifest=deepcopy(connector_manifest),
+                    parameter_name=parameter_name,
+                )
+
             dict_of_outputs[parameter_name] = action_parameter_values
 
         # we need to take the name foe the action from the entrypoint section of the manifest file and not the id section
@@ -204,6 +306,7 @@ def get_actions(connector_manifest: dict) -> dict:
             "description": action.get("description", "test_description").removesuffix("."),
             "input": dict_of_inputs,
             "output": dict_of_outputs,
+            "action_type": action.get("type"),
         }
 
     return actions
@@ -239,25 +342,32 @@ def format_action_parameter_values(
     return (
         connector_manifest.get("components", {})
         .get("parameters", {})
-        .get(parameter_name)
+        .get(parameter_name, {})
     )
 
 
-def process_action(connector_manifest: dict = {}, parameter_name: str = "", action_parameter_values: dict = {}) -> Tuple[str, dict]:
+def process_action(
+    connector_manifest: Optional[dict] = None,
+    parameter_name: str = "",
+    action_parameter_values: Optional[dict] = None,
+) -> Tuple[str, dict]:
     """
     To take the raw parameter info that was extracted formated he manifest.yaml file and
     convert it to a format that will be used by the plugin.spec.yaml file
 
     :param dict connector_manifest: A dict object created from reading in the manifest.yaml file
     :param str parameter_name: The name of the parameter within the action that is being formatted
+    :param dict action_parameter_values: The raw action parameter values that are being formatted
     :return Tuple[str, dict]: The formatted name of the action parameter, The formatted contents of the action parameter
     """
-
+    connector_manifest = connector_manifest or {}
     if not action_parameter_values:
         action_parameter_values = format_action_parameter_values(
             connector_manifest=deepcopy(connector_manifest),
             parameter_name=parameter_name,
         )
+    else:
+        action_parameter_values = deepcopy(action_parameter_values)
 
     # connectors use the key of nullable rather than required so we need to swap that
     # as nullable true means its not required we need the inverse of this field
@@ -282,9 +392,8 @@ def process_action(connector_manifest: dict = {}, parameter_name: str = "", acti
         action_parameter_values["type"] = "password"
 
     for key, value in action_parameter_values.items():
-        if key not in ["name", "description"]:
-            if value == "number":
-                action_parameter_values[key] = "float"
+        if key not in ["name", "description"] and value == "number":
+            action_parameter_values[key] = "float"
 
     # removing an full stops from descriptions
     if action_parameter_values.get("description"):
@@ -383,12 +492,10 @@ def format_title(title: str) -> str:
                 title_string = f"{title_string} {low_value.capitalize()}"
             else:
                 title_string = f"{title_string} {low_value}"
-
+        elif len(value) > 1:
+            title_string = f"{title_string} {value[0].upper() + value[1:]}"
         else:
-            if len(value) > 1:
-                title_string = f"{title_string} {value[0].upper() + value[1:]}"
-            else:
-                title_string = f"{title_string} {value.capitalize()}"
+            title_string = f"{title_string} {value.capitalize()}"
 
     # make sure there no whitespace and not full stops
     title_string = title_string.strip()
@@ -396,21 +503,34 @@ def format_title(title: str) -> str:
 
     return title_string
 
+
 def get_user_type(connector_folder: str) -> str:
     """
     If there is json files, they need to be modified, so making the user root to have permissions
 
-    :param str connector_folder: The patch to the source folder of the connector
+    :param str connector_folder: The path to the source folder of the connector
     :return str: The user that will be used
     """
-    
+
     app_folder = ""
     for directory in os.listdir(connector_folder):
         if directory.endswith('_app'):
             app_folder = os.path.join(connector_folder, directory)
+            break
 
     if not app_folder:
-        raise SystemError(f"No app_folder was found in {connector_folder}")
+
+        # if there is no app folder, this is a Surcom Connector and
+        # check if there is a 'functions' folder
+        functions_folder = os.path.join(connector_folder, "functions")
+
+        if os.path.exists(functions_folder):
+            app_folder = functions_folder
+
+        else:
+            # If there is no app folder or functions folder, we can't proceed
+            # so we will raise an error
+            raise SystemError(f"No app_folder or functions_folder were found in {connector_folder}")
 
 
     # cdodge: this hard coded servicenow path seems wrong and throws an
@@ -462,7 +582,7 @@ def format_spec_file( # pylint: disable=too-many-positional-arguments
     new_spec_file["products"] = ["insightconnect"]
     new_spec_file["name"] = name
     new_spec_file["title"] = title
-    new_spec_file["description"] = f"{connector_manifest.get('description')}"
+    new_spec_file["description"] = "PLACEHOLDER"
     new_spec_file["version"] = version
     new_spec_file["connection_version"] = connection_version
     new_spec_file["supported_versions"] = ["PLACEHOLDER"]
@@ -496,5 +616,6 @@ def format_spec_file( # pylint: disable=too-many-positional-arguments
 
     new_spec_file["original_connector_name"] = f"{connector_manifest.get('id')}"
     new_spec_file["original_connector_version"] = f"v{connector_manifest.get('version')}"
+    new_spec_file["enable_cache"] = True
 
     return new_spec_file
