@@ -1,6 +1,6 @@
 import ast
 import os
-import shutil
+import re
 from functools import singledispatch
 from typing import Dict, List, Union
 
@@ -14,9 +14,6 @@ from insight_plugin import (
 from insight_plugin.features.connector_to_plugin.help.constants import (
     FileExtensionsConstants,
 )
-from insight_plugin.features.common.plugin_spec_util import (
-    PluginSpecUtil,
-)
 from insight_plugin.features.common.exceptions import InsightException
 from insight_plugin.features.common.plugin_spec_util import (
     PluginSpecConstants as Constants,
@@ -59,6 +56,15 @@ from insight_plugin.features.connector_to_plugin.models.plugin_schem import (
 )
 
 list_of_archived_packages = []
+_ACTION_TYPE_TO_TEMPLATE = {
+    None: 'connector/actions/action/action.py.jinja',
+    'import': 'connector/actions/action/action_import.py.jinja',
+}
+
+_INTERNAL_REQUIREMENTS: List[str] = [
+    'noetic-connector-api',
+    'r7-surcom-api',
+]
 
 
 def create_action_py( # pylint: disable=too-many-positional-arguments
@@ -68,6 +74,7 @@ def create_action_py( # pylint: disable=too-many-positional-arguments
     action_dir_name: str,
     connector_name: str,
     source_dir_name: str,
+    template_filename: str,
 ) -> None:
     """
     Creates the action.py for a plugin action.
@@ -93,7 +100,7 @@ def create_action_py( # pylint: disable=too-many-positional-arguments
         action_spec_input = {}
 
     create_file_from_template(
-        template_filename="connector/actions/action/action.py.jinja",
+        template_filename=template_filename,
         inputs={
             "base_module": BASE_MODULE,
             "action": action_name,
@@ -191,6 +198,7 @@ def create_actions(
                 target_dir_name=action_dir_name,
             )
         )
+        action_type = spec.get(Constants.ACTIONS, {}).get(action_name, {}).get('action_type')
         create_action_py(
             spec=spec,
             action_name=action_name,
@@ -200,6 +208,7 @@ def create_actions(
             action_dir_name=action_dir_name,
             connector_name=connector_name,
             source_dir_name=source_dir_name,
+            template_filename=_ACTION_TYPE_TO_TEMPLATE[action_type],
         )
         create_schema(
             ActionSchemaSpec(
@@ -353,8 +362,8 @@ def find_function_import(
     :return:
     """
 
-
     app_folder_path = ""
+
     for root, dirs, _ in os.walk(source_dir_name):
         # Check if any subdirectory starts with the given prefix
         for dir_name in dirs:
@@ -362,23 +371,34 @@ def find_function_import(
                 app_folder_path = (os.path.join(root, dir_name))
                 break
 
-    init_file = os.path.join(app_folder_path, "__init__.py")
+    if not app_folder_path:
+        # if there is no app folder, this is a Surcom Connector and
+        # check if there is a 'functions' folder
+        functions_folder = os.path.join(source_dir_name, "functions")
+        function_source_file = f"fn_{function_name}"
+        function_source_path = os.path.join(functions_folder, f"{function_source_file}.py")
 
-    print(f"{init_file = }")
+        if os.path.exists(functions_folder) and os.path.exists(function_source_path):
+            return f"from {connector_name}.util.functions.{function_source_file} import {function_name}"
 
-    with open(init_file, "r", encoding="utf-8") as file:
-        file_content = file.read()
+    if app_folder_path:
+        init_file = os.path.join(app_folder_path, "__init__.py")
 
-    # Parse the content of the file to an Abstract Syntax Tree (AST)
-    tree = ast.parse(file_content)
+        print(f"{init_file = }")
 
-    # Iterate through all nodes in the AST
-    for node in ast.walk(tree):
-        # Check if the node is a 'from ... import ...' statement
-        if isinstance(node, ast.ImportFrom):
-            for alias in node.names:
-                if function_name == alias.name:
-                    return f"from {connector_name}.util.{node.module.rstrip('.py')} import {alias.name}"
+        with open(init_file, "r", encoding="utf-8") as file:
+            file_content = file.read()
+
+        # Parse the content of the file to an Abstract Syntax Tree (AST)
+        tree = ast.parse(file_content)
+
+        # Iterate through all nodes in the AST
+        for node in ast.walk(tree):
+            # Check if the node is a 'from ... import ...' statement
+            if isinstance(node, ast.ImportFrom):
+                for alias in node.names:
+                    if function_name == alias.name:
+                        return f"from {connector_name}.util.{node.module.rstrip('.py')} import {alias.name}"
 
     return ""
 
@@ -443,6 +463,10 @@ def create_connection(
     print("Created connection")
 
 
+def _normalize_package_name(name):
+    return re.sub(r"[-_.]+", "-", name).lower().strip()
+
+
 def create_requirements_txt(target_dir_name: str, source_dir_name: str) -> None:
     """
     Creates the requirements.txt for the plugin, based on the source plugin requirements.txt
@@ -452,15 +476,14 @@ def create_requirements_txt(target_dir_name: str, source_dir_name: str) -> None:
     """
     output_file = os.path.join(target_dir_name, "requirements.txt")
     source_requirements = os.path.join(source_dir_name, "requirements.txt")
+    internal_requirements_file = os.path.join(target_dir_name, "internal-requirements.txt")
 
     with open(source_requirements, "r", encoding="utf-8") as file:
         content = ""
+        internal_requirements: List[str] = []
         for line in file:
             package = line.rstrip("\n")
-            # the noetic_connector_api will be installed in the docker file
-            if package == "noetic_connector_api":
-                pass
-            elif package.endswith(FileExtensionsConstants.GZ) or package.endswith(
+            if package.endswith(FileExtensionsConstants.GZ) or package.endswith(
                 FileExtensionsConstants.ZIP
             ):
                 copy_archived_packages(
@@ -469,6 +492,8 @@ def create_requirements_txt(target_dir_name: str, source_dir_name: str) -> None:
                     package=package,
                 )
                 list_of_archived_packages.append(package)
+            elif _normalize_package_name(package) in _INTERNAL_REQUIREMENTS:
+                internal_requirements.append(package)
             else:
                 content += line
 
@@ -479,6 +504,8 @@ def create_requirements_txt(target_dir_name: str, source_dir_name: str) -> None:
             },
             output_filename=output_file,
         )
+        with open(internal_requirements_file, "w", encoding=FILE_ENCODING) as file:
+            file.write("\n".join(internal_requirements))
 
 
 def create_dockerignore(target_dir_name: str, connector_name_prefixed: str):
@@ -499,6 +526,29 @@ def create_dockerignore(target_dir_name: str, connector_name_prefixed: str):
     )
 
 
+def create_entrypoint(
+    spec: PluginSpecTypes.Spec,
+    target_dir_name: str,
+    prefix: str,
+):
+    """
+    Creates the entrypoint.sh for the plugin.
+    :param spec: The plugin spec with values to fill in to the Dockerfile
+    :param target_dir_name: The absolute path to the target directory
+    :param prefix: The prefix, either icon or komand
+    :return:
+    """
+    output_file = os.path.join(target_dir_name, "entrypoint.sh")
+    create_file_from_template(
+        template_filename="connector/entrypoint.sh.jinja",
+        inputs={
+            "plugin_name": spec["name"],
+            "prefix": prefix,
+        },
+        output_filename=output_file,
+    )
+
+
 def create_dockerfile(spec: PluginSpecTypes.Spec, target_dir_name: str, prefix: str):
     """
     Creates the Dockerfile for the plugin.
@@ -597,6 +647,11 @@ def create_files_connector_to_plugin(
     create_dockerignore(
         target_dir_name=target_dir_name, connector_name_prefixed=connector_name_prefixed
     )
+    create_entrypoint(
+        spec=spec,
+        target_dir_name=target_dir_name,
+        prefix=prefix,
+    )
     create_dockerfile(spec=spec, target_dir_name=target_dir_name, prefix=prefix)
     create_init(
         source_init=CreatePluginInit(
